]> asedeno.scripts.mit.edu Git - linux.git/commitdiff
mm: memcg/slab: rename slab delayed deactivation functions and fields
authorRoman Gushchin <guro@fb.com>
Fri, 12 Jul 2019 03:56:06 +0000 (20:56 -0700)
committerLinus Torvalds <torvalds@linux-foundation.org>
Fri, 12 Jul 2019 18:05:44 +0000 (11:05 -0700)
The delayed work/rcu deactivation infrastructure of non-root kmem_caches
can be also used for asynchronous release of these objects.  Let's get rid
of the word "deactivation" in corresponding names to make the code look
better after generalization.

It's easier to make the renaming first, so that the generalized code will
look consistent from scratch.

Let's rename struct memcg_cache_params fields:
  deact_fn -> work_fn
  deact_rcu_head -> rcu_head
  deact_work -> work

And RCU/delayed work callbacks in slab common code:
  kmemcg_deactivate_rcufn -> kmemcg_rcufn
  kmemcg_deactivate_workfn -> kmemcg_workfn

This patch contains no functional changes, only renamings.

Link: http://lkml.kernel.org/r/20190611231813.3148843-3-guro@fb.com
Signed-off-by: Roman Gushchin <guro@fb.com>
Acked-by: Vladimir Davydov <vdavydov.dev@gmail.com>
Reviewed-by: Shakeel Butt <shakeelb@google.com>
Cc: Christoph Lameter <cl@linux.com>
Cc: Johannes Weiner <hannes@cmpxchg.org>
Cc: Michal Hocko <mhocko@suse.com>
Cc: Waiman Long <longman@redhat.com>
Cc: David Rientjes <rientjes@google.com>
Cc: Joonsoo Kim <iamjoonsoo.kim@lge.com>
Cc: Pekka Enberg <penberg@kernel.org>
Cc: Andrei Vagin <avagin@gmail.com>
Cc: Qian Cai <cai@lca.pw>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
Signed-off-by: Linus Torvalds <torvalds@linux-foundation.org>
include/linux/slab.h
mm/slab.h
mm/slab_common.c

index 98c3d12b7275bce7d97af2b69e185c747a3e9a31..6008d884e6210d307802c56f66f94939266e99e2 100644 (file)
@@ -643,10 +643,10 @@ struct memcg_cache_params {
                        struct list_head children_node;
                        struct list_head kmem_caches_node;
 
-                       void (*deact_fn)(struct kmem_cache *);
+                       void (*work_fn)(struct kmem_cache *);
                        union {
-                               struct rcu_head deact_rcu_head;
-                               struct work_struct deact_work;
+                               struct rcu_head rcu_head;
+                               struct work_struct work;
                        };
                };
        };
index 86f7ede21203e9fa92df1470baae7b18b388f6fb..7ef695b91919049ad324169697752e54f3aebe20 100644 (file)
--- a/mm/slab.h
+++ b/mm/slab.h
@@ -291,7 +291,7 @@ static __always_inline void memcg_uncharge_slab(struct page *page, int order,
 extern void slab_init_memcg_params(struct kmem_cache *);
 extern void memcg_link_cache(struct kmem_cache *s, struct mem_cgroup *memcg);
 extern void slab_deactivate_memcg_cache_rcu_sched(struct kmem_cache *s,
-                               void (*deact_fn)(struct kmem_cache *));
+                               void (*work_fn)(struct kmem_cache *));
 
 #else /* CONFIG_MEMCG_KMEM */
 
index 07ee4189b40ce8d701cfe9e327b6a4ef0e5cfa62..f4dd9f75751cbf109c2641650ae6112e5404b8c9 100644 (file)
@@ -691,17 +691,17 @@ void memcg_create_kmem_cache(struct mem_cgroup *memcg,
        put_online_cpus();
 }
 
-static void kmemcg_deactivate_workfn(struct work_struct *work)
+static void kmemcg_workfn(struct work_struct *work)
 {
        struct kmem_cache *s = container_of(work, struct kmem_cache,
-                                           memcg_params.deact_work);
+                                           memcg_params.work);
 
        get_online_cpus();
        get_online_mems();
 
        mutex_lock(&slab_mutex);
 
-       s->memcg_params.deact_fn(s);
+       s->memcg_params.work_fn(s);
 
        mutex_unlock(&slab_mutex);
 
@@ -712,36 +712,36 @@ static void kmemcg_deactivate_workfn(struct work_struct *work)
        css_put(&s->memcg_params.memcg->css);
 }
 
-static void kmemcg_deactivate_rcufn(struct rcu_head *head)
+static void kmemcg_rcufn(struct rcu_head *head)
 {
        struct kmem_cache *s = container_of(head, struct kmem_cache,
-                                           memcg_params.deact_rcu_head);
+                                           memcg_params.rcu_head);
 
        /*
-        * We need to grab blocking locks.  Bounce to ->deact_work.  The
+        * We need to grab blocking locks.  Bounce to ->work.  The
         * work item shares the space with the RCU head and can't be
         * initialized eariler.
         */
-       INIT_WORK(&s->memcg_params.deact_work, kmemcg_deactivate_workfn);
-       queue_work(memcg_kmem_cache_wq, &s->memcg_params.deact_work);
+       INIT_WORK(&s->memcg_params.work, kmemcg_workfn);
+       queue_work(memcg_kmem_cache_wq, &s->memcg_params.work);
 }
 
 /**
  * slab_deactivate_memcg_cache_rcu_sched - schedule deactivation after a
  *                                        sched RCU grace period
  * @s: target kmem_cache
* @deact_fn: deactivation function to call
  *
* Schedule @deact_fn to be invoked with online cpus, mems and slab_mutex
  * held after a sched RCU grace period.  The slab is guaranteed to stay
* alive until @deact_fn is finished.  This is to be used from
  * __kmemcg_cache_deactivate().
  */
 void slab_deactivate_memcg_cache_rcu_sched(struct kmem_cache *s,
-                                          void (*deact_fn)(struct kmem_cache *))
+                                          void (*work_fn)(struct kmem_cache *))
 {
        if (WARN_ON_ONCE(is_root_cache(s)) ||
-           WARN_ON_ONCE(s->memcg_params.deact_fn))
+           WARN_ON_ONCE(s->memcg_params.work_fn))
                return;
 
        if (s->memcg_params.root_cache->memcg_params.dying)
@@ -750,8 +750,8 @@ void slab_deactivate_memcg_cache_rcu_sched(struct kmem_cache *s,
        /* pin memcg so that @s doesn't get destroyed in the middle */
        css_get(&s->memcg_params.memcg->css);
 
-       s->memcg_params.deact_fn = deact_fn;
-       call_rcu(&s->memcg_params.deact_rcu_head, kmemcg_deactivate_rcufn);
+       s->memcg_params.work_fn = work_fn;
+       call_rcu(&s->memcg_params.rcu_head, kmemcg_rcufn);
 }
 
 void memcg_deactivate_kmem_caches(struct mem_cgroup *memcg)
@@ -712,36 +712,36 @@ static void kmemcg_deactivate_workfn(struct work_struct *work)
  *                                        sched RCU grace period
  * @s: target kmem_cache
- * @deact_fn: deactivation function to call
+ * @work_fn: deactivation function to call
  *
@@ -712,36 +712,36 @@ static void kmemcg_deactivate_workfn(struct work_struct *work)
  *
- * Schedule @deact_fn to be invoked with online cpus, mems and slab_mutex
+ * Schedule @work_fn to be invoked with online cpus, mems and slab_mutex
  * held after a sched RCU grace period.  The slab is guaranteed to stay
@@ -712,36 +712,36 @@ static void kmemcg_deactivate_workfn(struct work_struct *work)
  * held after a sched RCU grace period.  The slab is guaranteed to stay
- * alive until @deact_fn is finished.  This is to be used from
+ * alive until @work_fn is finished.  This is to be used from
  * __kmemcg_cache_deactivate().
  */